<?php
/**
 * Corethinker functions and definitions
 *
 * @package Corethinker
 */

add_filter('sanitize_option_corethinkertheme_options', 'corethinkertheme_sanitize_options');

function corethinkertheme_sanitize_options($arr) {
	$defaults = array(
		'logo_enabled' => 'Y',
		'site_title_enabled' => 'Y',
		'site_description_enabled' => 'Y',
		'navbar_brand' => 'Project Name',
		'navbar_location' => 'default',
		'navbar_gradient' => 'Y',
		'copyright' => date('Y ') . get_option('blogname'),
		'show_home' => 'N',
		'reduce_404_page' => 'N',
		'disable_comment_page' => 'N',
		'sidebar_main' => 'right',
		'sidebar_top' => 'Y',
		'sidebar_bottom' => 'Y',
		'panel_widget' => 'N', 
		'panel_post' => 'N',
		'carousel' => 'demo',
		'disable_slide_the_content' => 'N',
		'image_rounded' => 'N',
		'prev_next_link' => 'titles',
		'paginate_links' => 'next',
		'credits' => 'Y',
		'post_thumbnail' => 'Y',
		'post_date' => 'Y',
		'post_author' => 'Y',
		'excerpt' => 'N',
		'text_color' => '#333333',
		'headers_color' => '',
		'link_color' => '',
		'link_hover_color' => '',
		'navbar_color' => '',
		'navbar_color2' => '',
		'navbar_border' => '',
		'navbar_link_color' => '',
		'navbar_link_color2' => '',
		'page_bgcolor' => '',
		'slides' => array(),
	);

	$out = array();
	foreach ($defaults as $key => $value) {
		$out[$key] = isset($arr[$key]) ? $arr[$key] : $value;
		if (strpos($key, 'color') && !preg_match('/^#[0-9a-f]{6,6}$/i', $out[$key])) {
			$out[$key] = '';
		}

		if ( 'slides' == $key ) {
			$slides = array(0);
			foreach($out[$key] as $slide_raw) {
				if (is_array($slide_raw)) {
					$slide['title'] = sanitize_text_field($slide_raw['title']);
					$slide['src'] = sanitize_text_field($slide_raw['src']);
					$slide['alt'] = sanitize_text_field($slide_raw['alt']);
					$slide['link'] = sanitize_text_field($slide_raw['link']);
					$slide['content'] = trim($slide_raw['content']);
					if ($slide['src']) {
						$slides[] = $slide;
					}
				}
			}
			unset($slides[0]);
			$out[$key] = $slides;
		}
	}

	$out = stripslashes_deep($out);

	if ($out['text_color']) {
		$out['text_color2'] = corethinkertheme_smudge_color($out['text_color'], 40);
	}
	else {
		$out['text_color'] = $out['text_color2'] = '';
	}

	if ($out['link_color']) {
		$out['link_hover_color'] = corethinkertheme_darken($out['link_color'], 15);
	}
	else {
		$out['link_color'] = $out['link_hover_color'] = '';
	}
	if ($out['navbar_color']) {
		$out['navbar_color2'] = corethinkertheme_lighten($out['navbar_color'], 75);
		$out['navbar_border'] = corethinkertheme_lighten($out['navbar_color'], 25);
	}
	else {
		$out['navbar_color'] = $out['navbar_color2'] = $out['navbar_border'] = '';
	}
	if ($out['navbar_link_color']) {
		$out['navbar_link_color2'] = corethinkertheme_darken($out['navbar_link_color'], 40);
	}
	else {
		$out['navbar_link_color'] = $out['navbar_link_color2'] = '';
	}
	$out['copyright'] = htmlspecialchars($out['copyright']);
	$out['navbar_brand'] = htmlspecialchars($out['navbar_brand']);
	return $out;
}

function corethinkertheme_darken($color, $percent) {
	$p = min(abs($percent), 100);
	$ratio = 1 - $p*0.01;
	$dec = hexdec(substr($color, 1));
	$b = dechex(floor((0xFF & $dec) * $ratio));
	if (strlen($b) == 1) $b = '0'.$b;
	$g = dechex(floor(((0xFF00 & $dec) >> 8) * $ratio));
	if (strlen($g) == 1) $g = '0'.$g;
	$r = dechex(floor(((0xFF0000 & $dec) >> 16) * $ratio));
	if (strlen($r) == 1) $r = '0'.$r;
	return "#$r$g$b";
}

function corethinkertheme_lighten($color, $percent) {
	$p = min(abs($percent), 100);
	$ratio =  1 + $p*0.01;
	$dec = hexdec(substr($color, 1));
	$b = dechex(min( floor((0xFF & $dec) * $ratio), 255 ));
	if (strlen($b) == 1) $b = '0'.$b;
	$g = dechex(min( floor(((0xFF00 & $dec) >> 8) * $ratio), 255 ));
	if (strlen($g) == 1) $g = '0'.$g;
	$r = dechex(min( floor(((0xFF0000 & $dec) >> 16) * $ratio), 255 ));
	if (strlen($r) == 1) $r = '0'.$r;
	return "#$r$g$b";
}

function corethinkertheme_smudge($c, $r) {
	$x = dechex(floor($c*(1-$r) + (255-$c)*$r));				
	if (strlen($x) == 1) $b = '0'.$x;
	return $x;
}

function corethinkertheme_smudge_color($color, $percent) {
	$p = min(abs($percent), 100);
	$ratio = $p*0.01;
	$dec = hexdec(substr($color, 1));
	$b = corethinkertheme_smudge(0xFF & $dec, $ratio);
	$g = corethinkertheme_smudge((0xFF00 & $dec) >> 8, $ratio);
	$r = corethinkertheme_smudge((0xFF0000 & $dec) >> 16, $ratio);
	return "#$r$g$b";
}

function corethinkertheme_admin_init() {
	global $corethinkertheme_options;
	register_setting('corethinkertheme-settings-group', 'corethinkertheme_options');

	if ( !empty($_GET['noheader']) && 'corethinkertheme_save_file' == $_GET['action']) {
		$str = serialize($corethinkertheme_options);
		if ( empty($str) ) die;
		header("Content-Type: application/octet-stream;");
		header('Content-Disposition: attachment; filename='. 'corethinkertheme-settings-'. date('YmdHis') .'.txt');
		header('Accept-Ranges: bytes');
		header('Content-Length: '.strlen($str));
		die($str);
	}
	add_action('admin_notices', 'corethinkertheme_update_options_notice');
	if ( !empty($_POST['corethinkertheme_action']) ) {
		$corethinkertheme_action = preg_replace('/[^a-z0-9_]/', '', $_POST['corethinkertheme_action']);
		if ( !wp_verify_nonce( $_POST['_wpnonce'], 'corethinkertheme-settings-group-options' ) ) {
			wp_die( 'Invalid or expired nonce marker.' ); 
		}
		switch ($corethinkertheme_action) {
			case 'upload':
				if ( ($file = $_FILES['corethinkertheme_upload_settings']) && !$file['error'] && $file['size']) {
					require_once ABSPATH . 'wp-admin/includes/class-wp-filesystem-base.php';
					require_once ABSPATH . 'wp-admin/includes/class-wp-filesystem-direct.php';
					$f = new WP_Filesystem_Direct('');
					$content = $f->get_contents($file['tmp_name']);
// I can obtain it by one call file get contents but Theme-Check grumbles
					$import = maybe_unserialize($content);
					$f->delete($file['tmp_name']);
					if (is_array($import)) {
						update_option('corethinkertheme_options', $import);
					}
					else {
						$corethinkertheme_action = 'import_failed';
					}
				}
				else {
					$corethinkertheme_action = 'import_failed';
				}
				break;
			case 'reset':
				update_option('corethinkertheme_options', array());
				break;
			case 'update':
				$corethinkertheme_new_options = array_merge($corethinkertheme_options, $_POST['corethinkertheme_options']);
				update_option('corethinkertheme_options', $corethinkertheme_new_options);
				break;
		}
		wp_redirect( admin_url('themes.php?page=corethinkertheme_settings&notice=' . $corethinkertheme_action) );
		die;
	}
}

function corethinkertheme_option_input($option_key, $name = '', $type = 'text', $default = '', $options = array()) {
	switch ($type) {
		case 'radio':
			echo '<label>' . $name . '</label>';
			$arr = $options ? $options : array('Y' => __('Yes', 'corethinkertheme'), 'N' => __('No', 'corethinkertheme'));
			foreach ($arr as $key => $value ) {
				echo ' <input name="corethinkertheme_options[' . $option_key . ']" type="radio" value="'. $key . '" '
					. (corethinkertheme_option($option_key) == $key ? 'checked' : ''). '/>'. $value . '&nbsp;';
			}
			break;

		case 'checkbox':
			echo '<input name="corethinkertheme_options[' . $option_key . ']" type="hidden" value="N" />';
			echo '<label>' . $name . '</label>';
			echo ' <input name="corethinkertheme_options[' . $option_key . ']" type="checkbox" value="Y" '
				. ('Y' == corethinkertheme_option($option_key) ? ' checked' : ''). '/>';  
			break;

		case 'color':
				echo '<label>' . $name . '</label>';
				echo '<input name="corethinkertheme_options[' . $option_key . ']" class="corethinkertheme-color-option" data-default-color="'
					. $default . '" type="text" value="' . corethinkertheme_option($option_key) . '" />';
		break;

		case 'text':
			echo '<label>' . $name . '</label>';
			echo '<input name="corethinkertheme_options[' . $option_key . ']" type="text" value="' . corethinkertheme_option($option_key) . '" />';
		break;

		case 'hidden':
			echo '<input name="corethinkertheme_options[' . $option_key . ']" type="hidden" value="' . corethinkertheme_option($option_key) . '" />';
		break;

		default:
			echo '<label>' . $name . '</label>';
			echo '<input name="corethinkertheme_options[' . $option_key . ']" type="text" value="' . corethinkertheme_option($option_key) . '" />';  
	}
}

function corethinkertheme_update_options_notice() {
	if ( empty($_GET['notice']) ) return;
	$type = 'updated';
	switch($_GET['notice']) {
		case 'update':
			$message = __('Theme settings have been updated.', 'corethinkertheme');
			break;
		case 'reset':
			$message = __('Theme settings have been reset.', 'corethinkertheme');
			break;
		case 'upload':
			$message = __('Theme settings have been imported from the uploded file.', 'corethinkertheme');
			break;
		case 'import_failed':
			$type = 'error';
			$message = __('Error: theme settings import failed.', 'corethinkertheme');
			break;
	}
	if ( !empty($message) ) {
		echo '<div id="message" class="'. $type . ' "><p>' . $message . '</p></div>';
	}
}

function corethinkertheme_settings_page() {
	global $corethinkertheme_options;
?>
<div class="wrap"><div id="icon-themes" class="icon32"><br></div>
<h2><?php _e('Corethinker Custom Settings', 'corethinkertheme'); ?></h2>
<form method="post" action="themes.php?page=corethinkertheme_settings" id="corethinkertheme_options_form" enctype="multipart/form-data">
	<?php settings_fields('corethinkertheme-settings-group'); ?>

<div class="corethinkertheme-settings-wrap">
	<ul class="corethinkertheme-settings-tabs">
		<li class="tab-active"><a href="#corethinkertheme-site-branding"><?php _e('Site Branding', 'corethinkertheme'); ?></a></li>
		<li><a href="#corethinkertheme-custom-colors"><?php _e('Custom Colors', 'corethinkertheme'); ?></a></li>
		<li><a href="#corethinkertheme-page-structure"><?php _e('Page Structure', 'corethinkertheme'); ?></a></li>
		<li><a href="#corethinkertheme-posts-look"><?php _e('Posts Look', 'corethinkertheme'); ?></a></li>
		<li><a href="#corethinkertheme-slides"><?php _e('Slides', 'corethinkertheme'); ?></a></li>
		<li><a href="#corethinkertheme-backup-restore"><?php _e('Backup/Restore', 'corethinkertheme'); ?></a></li>
		<li><a href="#corethinkertheme-display-all"><?php _e('Display All', 'corethinkertheme'); ?></a></li>
		<?php do_action('corethinkertheme_settings_list_items'); ?>
	</ul>

		<div class="corethinkertheme-settings-section corethinkertheme-site-branding">
			<h3><?php _e('Site Branding', 'corethinkertheme'); ?></h3>
			<div> <?php corethinkertheme_option_input('logo_enabled', __('Display logo', 'corethinkertheme'), 'checkbox'); ?> </div>
			<div> <?php corethinkertheme_option_input('site_title_enabled', __('Display site title?', 'corethinkertheme'), 'checkbox'); ?> </div>
			<div> <?php corethinkertheme_option_input('site_description_enabled', __('Display site description?', 'corethinkertheme'), 'checkbox'); ?></div>
			<div> <?php corethinkertheme_option_input('navbar_brand', __('Menu Bar title', 'corethinkertheme'), 'text'); ?></div>
			<div> <?php
				$nav_loc = array('default' => __('default', 'corethinkertheme'), 'disable' => __('disable', 'corethinkertheme'),
					'top' => __('top', 'corethinkertheme'), 'fixed-top' => __('fixed top', 'corethinkertheme'),
					'fixed-bottom' => __('fixed bottom', 'corethinkertheme'), 'full-width' => __('full width', 'corethinkertheme'));
				corethinkertheme_option_input('navbar_location', __('Menu Location', 'corethinkertheme'), 'radio', 'default', $nav_loc) ?></div>
			<div> <?php corethinkertheme_option_input('copyright', __('Copyright text', 'corethinkertheme'), 'text'); ?></div>
			<div> <?php corethinkertheme_option_input('credits', __('Display credits', 'corethinkertheme'), 'checkbox') ?></div>

		</div>
		<div class="corethinkertheme-settings-section corethinkertheme-custom-colors">
			<h3><?php _e('Custom Colors', 'corethinkertheme'); ?></h3>
			<div> <?php corethinkertheme_option_input('text_color', __('Text color', 'corethinkertheme'), 'color', '#333333'); ?></div>
			<div> <?php corethinkertheme_option_input('headers_color', __('Headers H1...H6 Color', 'corethinkertheme'), 'color') ?></div>
			<div> <?php corethinkertheme_option_input('link_color', __('Link color', 'corethinkertheme'), 'color') ?></div>
			<div> <?php corethinkertheme_option_input('navbar_color', __('Menu bar color', 'corethinkertheme'), 'color', '#F8F8F8'); ?></div>
			<div> <?php corethinkertheme_option_input('navbar_gradient', __('Menu bar gradient', 'corethinkertheme'), 'checkbox'); ?></div>
			
			<div> <?php corethinkertheme_option_input('navbar_link_color', __('Navigation link color', 'corethinkertheme'), 'color', '#777777'); ?></div>

			<div> <?php corethinkertheme_option_input('page_bgcolor', __('Page background color', 'corethinkertheme'), 'color', ''); ?></div>

		</div>


		<div class="corethinkertheme-settings-section corethinkertheme-page-structure">
			<h3><?php _e('Page Structure', 'corethinkertheme'); ?></h3>
			<div> <?php corethinkertheme_option_input('sidebar_main', __('Main sidebar', 'corethinkertheme'), 'radio', 'left',
				array('left'=> __('Left', 'corethinkertheme'), 'right'=> __('Right', 'corethinkertheme'),) ); ?></div>
			<div> <?php corethinkertheme_option_input('sidebar_top', __('Top sidebar', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('sidebar_bottom', __('Bottom sidebar', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('disable_comment_page', __('Disable comments on pages', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('panel_widget', __('Widget as panel', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('panel_post', __('Post as panel', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('show_home', __('Home link (in pages menu)', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('reduce_404_page', __('Reduce &quot;Not Found&quot; page', 'corethinkertheme'), 'checkbox') ?></div>

		</div>

		<div class="corethinkertheme-settings-section corethinkertheme-posts-look">
			<h3><?php _e('Posts Look', 'corethinkertheme'); ?></h3>
			<div> <?php corethinkertheme_option_input('excerpt', __('Excerpts in archives', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('post_thumbnail', __('Featured images in excerpts', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('post_date', __('Display post date', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('post_author', __('Display post author', 'corethinkertheme'), 'checkbox') ?></div>

			<div> <?php corethinkertheme_option_input('prev_next_link', __('Adjacent post links', 'corethinkertheme'), 'radio', 'titles',
				array('titles' => __('Titles', 'corethinkertheme'), 'prev_next' => __('Next/Previous', 'corethinkertheme'), 'disable' => __('Disable', 'corethinkertheme'))
			); ?></div>

			<div> <?php corethinkertheme_option_input('image_rounded', __('Rounded images', 'corethinkertheme'), 'checkbox') ?></div>
			<div> <?php corethinkertheme_option_input('paginate_links', __('Blog pagination', 'corethinkertheme'), 'radio', 'next',
				array('next' => __('Older/Newer', 'corethinkertheme'), 'number' => __('Numbers', 'corethinkertheme'),) ) ?></div>
		</div>

		<div class="corethinkertheme-settings-section corethinkertheme-slides">
			<h3><?php _e('Slides', 'corethinkertheme');?></h3>


			<p> <?php corethinkertheme_option_input('carousel', __('Homepage carousel', 'corethinkertheme'), 'radio', 'demo',
				array('Y' => __('Yes', 'corethinkertheme'), 'N' => __('No', 'corethinkertheme'), 'demo' => __('Demo', 'corethinkertheme'),)); ?></p>

			<p> <?php
				if (current_user_can('unfiltered_html')) {
					corethinkertheme_option_input('disable_slide_the_content', __('Disable &#39;the_content&#39; filter', 'corethinkertheme'), 'checkbox');
			}	?></p>

			<h3 class="edit-slides"><?php _e('Edit Slides', 'corethinkertheme');?></h3>


			<input type="hidden" name="corethinkertheme_options[slides][0]" value="dummy" />
			<?php $slides = corethinkertheme_option('slides');
				if ( !$slides ) {
					$slides[1] = array(
						'title'=> '', 'src'=> '', 'content'=> '', 'link'=> '', 'alt'=> '',
					);
				}
				foreach ($slides as $i => $slide) {
					echo '<div id="slide-' . $i . '" ><h4><span class="space"> </span>'
						. __('Slide', 'corethinkertheme') . ' #' . $i
						. ' &nbsp; <a class="slide-remove" href="#" onclick="corethinkertheme_remove_slide('. $i . ');">&times;</a></span></h4>';

					echo '<p><label for="corethinkertheme_options-slides-'. $i . '-title">'. __('Title', 'corethinkertheme')
						. '</label><input id="corethinkertheme_options-slides-'. $i . '-title" type="text" name="corethinkertheme_options[slides]['
						. $i . '][title]" value="' . $slides[$i]['title'] . '"></p>';
					echo '<p><label for="corethinkertheme_options-slides-'. $i . '-src">'
						. __('Image URL', 'corethinkertheme') . '</label><input class="corethinkertheme-slide-src" id="corethinkertheme_options-slides-' . $i
						. '-src" type="text" name="corethinkertheme_options[slides]['	. $i . '][src]" value="'
						. $slides[$i]['src'] . '" onchange="corethinkertheme_slide_preview_change(' . $i . ');"> </p>'
						. '<p><span class="space"> </span><a href="#" id="slide-url-choose-'. $i . '" class="button button-secondary slide-url-choose" onclick="corethinkertheme_slide_choose('
						. $i .');"><span class="media-icon"></span> ' . __('Choose', 'corethinkertheme') . '</a> <span class="slide-preview" id="slide-preview-'
						. $i .'">' . ($slides[$i]['src'] ? '<img src="' . $slides[$i]['src'] . '" alt="" /> ' : ''). '</span></p>';

					echo '<div><label class="slide-textarea-label" for="corethinkertheme_options-slides-' . $i . '-content">'. __('Description', 'corethinkertheme')
						. '</label></div>';

					echo '<div id="wp-corethinkertheme_options-slides-' . $i . '-content-wrap" class="slide-textarea-wrap"><textarea class="wp-editor-area" name="corethinkertheme_options[slides]['. $i .'][content]" rows="5" id="corethinkertheme_options-slides-' . $i . '-content">'
					. $slides[$i]['content'] . '</textarea></div>';
					echo '<p><label for="corethinkertheme_options-slides-'. $i . '-link">'. __('Link', 'corethinkertheme')
						. '</label><input id="corethinkertheme_options-slides-'. $i . '-link" type="text" name="corethinkertheme_options[slides]['.$i.'][link]" value="'
						. $slides[$i]['link'] . '"></p>';
					echo '<p><label for="corethinkertheme_options-slides-'. $i . '-alt">'. __('Alt text', 'corethinkertheme')
						. '</label><input id="corethinkertheme_options-slides-'. $i . '-alt" type="text" name="corethinkertheme_options[slides]['.$i.'][alt]" value="'
						. $slides[$i]['alt'] . '"></p>';
					echo '</div>';
				}
			?>
			<p><a name="add-new-slide" class="button button-secondary" href="#add-new-slide" onclick="corethinkertheme_add_new_slide();"><?php _e('Add new slide', 'corethinkertheme'); ?></a></p>
		</div>

		<div class="corethinkertheme-settings-section corethinkertheme-backup-restore">
			<h3><?php _e('Backup/Restore Settings', 'corethinkertheme'); ?></h3>
			<div><label><?php _e('Export Settings', 'corethinkertheme'); ?></label><a class="button button-secondary" href="themes.php?page=corethinkertheme_settings&amp;noheader=1&amp;action=corethinkertheme_save_file"><?php _e('Save as File', 'corethinkertheme'); ?></a></div>
			<p>&nbsp;</p>
			<div><?php _e('Import', 'corethinkertheme'); ?>:<br /> <input type="file" name="corethinkertheme_upload_settings" />
				<input class="button button-primary" type="button" value="<?php _e('Upload and Apply', 'corethinkertheme'); ?>" onclick="corethinkertheme_upload();" />
			</div>
			<p>&nbsp;</p>			
			<div>
				<label>&nbsp;</label><input type="button" class="button button-secondary" onclick="corethinkertheme_reset();" value="<?php _e('Reset Options', 'corethinkertheme'); ?>" />
			</div>

		</div>
<?php
	do_settings_sections('corethinkertheme_settings');
// (so an external plugin can add some output here)
?>
<p>&nbsp;</p>
	<p>
		<input name="corethinkertheme_save_options" type="submit" value="<?php _e('Save Settings', 'corethinkertheme'); ?>" class="button button-primary" id="corethinkertheme_save_options"> 
		<input type="hidden" id="corethinkertheme_action" name="corethinkertheme_action" value="update" />		
	</p>
</div>
</form>
<p>&nbsp;</p>
	<p><small><?php
	$readme = '<a href="' . CorethinkerTHEME_URI .'/readme.txt">readme.txt</a>';
	printf( __('Any questions? Look %1$s.', 'corethinkertheme'), $readme); ?></small></p>
</div>
<?php
}
